@@ -1,12 +1,13 @@
-context("sql")
-
 test_that("Correct SQL query is returned", {
-  expect_is(
+  expect_s3_class(
     tidypredict_sql(lm(mpg ~ wt, data = mtcars), dbplyr::simulate_dbi()),
     "sql"
   )
-  expect_is(
-    tidypredict_sql_interval(lm(mpg ~ wt, data = mtcars), dbplyr::simulate_dbi()),
+  expect_s3_class(
+    tidypredict_sql_interval(
+      lm(mpg ~ wt, data = mtcars),
+      dbplyr::simulate_dbi()
+    ),
     "sql"
   )
 })
